@@ -3157,11 +3157,12 @@ void per_node_error_log(POOL_CONNECTION_POOL *backend, int node_id, char *query,
 	POOL_CONNECTION_POOL_SLOT *slot = backend->slots[node_id];
 	char *message;
 
-	if (pool_extract_error_message(true, CONNECTION(backend, node_id), MAJOR(backend), true, &message) > 0)
+	if (pool_extract_error_message(true, CONNECTION(backend, node_id), MAJOR(backend), true, &message) == 1)
 	{
 		ereport(LOG,
 			(errmsg("%s: DB node id: %d backend pid: %d statement: \"%s\" message: \"%s\"",
 				 prefix, node_id, ntohl(slot->pid), query, message)));
+		pfree(message);
 	}
 }
 
